@@ -3,8 +3,9 @@
 # License: GNU Affero General Public License v3 (see file COPYING for details)
 
 
+import os
+from pathlib import Path
 from html import escape
-from os import path
 from django.conf import settings
 from django.db import models
 from django.utils.text import format_lazy
@@ -107,6 +108,10 @@ class Renderer(JsRenderer, JsCacheRenderer):
         #     data.update(revision_number=settings.SITE.kernel.lino_version)
         # else:
         data.update(revision_number=settings.SITE.kernel.code_mtime)
+        try:
+            data.update(mjs_timestamp=os.stat(Path(settings.STATIC_ROOT) / 'react' / 'main.js').st_mtime)
+        except FileNotFoundError:
+            pass
 
         if hasattr(settings.SITE, 'theme_name'):
             data.update(theme_name=settings.SITE.theme_name)
@@ -680,7 +685,7 @@ class Renderer(JsRenderer, JsCacheRenderer):
         for actor in self.actors_list:
             if actor.get_handle_name is not None:
                 continue
-            fn = path.join(*self.lino_js_parts_chunked(actor.actor_id))
+            fn = os.path.join(*self.lino_js_parts_chunked(actor.actor_id))
 
             def write(f):
                 f.write(py2js(self.actor2json(actor)))
